@@ -57,11 +57,11 @@ sub _build_sub_command_mapping {
     $ref_path =~ s/::/\//g;
     my $full_ref_path = $base_path . '/' . $ref_path;
 
-    my @target_paths = glob("$full_ref_path/*.pm");
+    my @target_paths = glob("\Q$full_ref_path\E/*.pm");
     my @target_class_names;
     for my $target_path (@target_paths) { 
         my $target = $target_path;
-        $target =~ s#$base_path\/$ref_path/##; 
+        $target =~ s#\Q$base_path\E\/$ref_path/##;
         $target =~ s/\.pm//;
 
         my $target_base_class = $class->_target_base_class;
