@@ -4,7 +4,7 @@ package UR::Util;
 use warnings;
 use strict;
 require UR;
-our $VERSION = "0.46"; # UR $VERSION;
+our $VERSION = "0.47"; # UR $VERSION;
 use Cwd;
 use Data::Dumper;
 use Clone::PP;
@@ -38,8 +38,8 @@ sub used_libs {
     for my $inc (@INC) {
         $inc =~ s/\/+$//;
         my $abs_inc = Cwd::abs_path($inc) || $inc; # should already be expanded by UR.pm
-        next if (grep { $_ =~ /^$abs_inc$/ } @compiled_inc);
-        next if (grep { $_ =~ /^$abs_inc$/ } @perl5lib);
+        next if (grep { $_ =~ /^\Q$abs_inc\E$/ } @compiled_inc);
+        next if (grep { $_ =~ /^\Q$abs_inc\E$/ } @perl5lib);
         next if ((File::Spec->splitdir($inc))[-1] eq $Config{archname});
         push @extra, $inc;
     }
